# Red-Dashboard (Fork of Neuro's Dashboard)
An easy-to-use interactive web Dashboard to control your Red-DiscordBot instance! Thank you very much to Neuro for the initial work!

## Overview
This project is an easy-to-use interactive web Dashboard to control your Red-DiscordBot instance, allowing for easier customization of settings and more interactive plugins to develop and get your bot ready for production. Using Discord Open Authentication, users will log into the Dashboard using their Discord account, ensuring that all users are only allowed to customize and view settings that they are explicitly given permission to control, providing a safe and secure experience for all users.

## Installation
To get started on setting up your Dashboard for your Red bot, please follow the installation instructions that can be found [here](https://red-web-dashboard.readthedocs.io/en/latest).

This project is supported on Windows, Mac OS X and Linux distributions, however is recommended on Linux distributions for security reasons. Support is not given for setting up your domain for your Dashboard other than any guides given for such, and contributors to the source code are not responsible for any security issues that arise as a result of not securely setting up the software.

## Support
If you wish to use this program and receive support for it, you must also give feedback and report any bugs you encounter. You can ask in the #support_aaa3a-cogs channel in the [cogs support server](https://discord.gg/GET4DVk).

## Legal
Red-Dashboard for Red-DiscordBot is released under [Affero General Public License v3](https://github.com/AAA3A-AAA3A/Red-Dashboard/blob/main/LICENSE).

For details about how this project manages your privacy, please review the following documents. By using this program, you acknowledge that you have read these documents and consent to having your data used in the ways described in such documents.
- [Cookie Policy](https://github.com/AAA3A-AAA3A/Red-Dashboard/blob/main/documents/Cookie%20Policy.md)
- [Privacy Policy](https://github.com/AAA3A-AAA3A/Red-Dashboard/blob/main/documents/Privacy%20Policy.md)
- [Third Parties Disclaimer](https://github.com/AAA3A-AAA3A/Red-Dashboard/blob/main/documents/Third%20Parties%20Disclaimer.md)

## Credits
I would like to thank the following, for all the contributions they have made that helped this become what it is today.
* Neuro Assassin, for its great initial work!
* TrustyJAID for its OAuth basic integration for third parties.
* Cog Creators, for making such an amazing bot.
* All the people who tested the Dashboard, and gave feedback.
* AppSeed & Creative Tim, for creating a template that I use as the base for the Dashboard.